@@ -1,13 +1,17 @@
 # fineract APIs run on https by default
+from fineract import ResourceNotFoundException
 from fineract.handlers import RequestHandler
 from fineract.objects.client import Client
 from fineract.objects.group import Group
+from fineract.objects.hook import Hook
 from fineract.objects.loan import Loan
 from fineract.objects.loan_product import LoanProduct
 from fineract.objects.org import Staff, Fund, Charge, Office
 from fineract.objects.report import Report
 from fineract.objects.role import Role
+from fineract.objects.user import User
 from fineract.pagination import PaginatedList
+from fineract.templates import TEMPLATES
 
 DEFAULT_BASE_URL = 'https://localhost/fineract-provider/api/v1'
 DEFAULT_TENANT = 'default'
@@ -288,6 +292,52 @@ class Fineract(object):
                 dict()
             )
 
+    def get_hooks(self, id=None):
+        """Returns an office with a matching id or all offices
+
+        :calls `GET /hooks/<id> <https://demo.openmf.org/api-docs/apiLive.htm#hooks_retrieve>`_
+
+        :param id: Office id
+        :rtype: :class:`fineract.objects.hook.Hook` or  :class:`fineract.pagination.PaginatedList` of
+            :class:`fineract.objects.hook.Hook`
+        """
+        if id:
+            return Hook(self.__request_handler,
+                          self.__request_handler.make_request(
+                              'GET',
+                              '/hooks/{}'.format(id),
+                          ), False)
+        else:
+            return PaginatedList(
+                Hook,
+                self.__request_handler,
+                '/hooks',
+                dict()
+            )
+
+    def get_users(self, id=None):
+        """Returns an user with a matching id or all users
+
+        :calls `GET /users/<id> <https://demo.openmf.org/api-docs/apiLive.htm#users_retrieve>`_
+
+        :param id: User id
+        :rtype: :class:`fineract.objects.user.User` or  :class:`fineract.pagination.PaginatedList` of
+            :class:`fineract.objects.user.User`
+        """
+        if id:
+            return User(self.__request_handler,
+                          self.__request_handler.make_request(
+                              'GET',
+                              '/users/{}'.format(id),
+                          ), False)
+        else:
+            return PaginatedList(
+                User,
+                self.__request_handler,
+                '/users',
+                dict()
+            )
+
     def raw_request(self, method, url, **kwargs):
         """Make a raw request to the Fineract API
 
@@ -297,3 +347,20 @@ class Fineract(object):
         :return: Returns dict/list object
         """
         return self.__request_handler.make_request(method, url, **kwargs)
+
+    def templates(self, template, extra=None, params=None):
+        """Retrieve a template
+        :param template: template name
+        :param extra:
+        :return:
+        """
+        template_url = TEMPLATES.get(template, '')
+        if not template_url:
+            raise ResourceNotFoundException(404, 'Template not found')
+        if extra:
+            template_url = template_url.format(extra)
+
+        if params:
+            template_url += '&' + params
+
+        return self.__request_handler.make_request('GET', '/' + template_url)
