@@ -103,6 +103,12 @@ class FineractObject(object):
     def _get_current_date():
         return datetime.datetime.today()
 
+    @staticmethod
+    def _to_camel_case(string):
+        string = string.title().replace('_', '')
+        return string[0].lower() + string[1:]
+
+
     def as_dict(self):
         """Return dictionary representation of a :class:`fineract.objects.fineract_object.FineractObject`
 
